.. _technologies:

Technologies
============


Flat design
-----------

Never heard about `material design <https://material.io/design>`_?
`This repo <https://pythonlang.dev/repo/anjalp-minimalistic-flat-modern-gui-template/>`_
was a good source of inspiration for the overall design of the GUI.

`material design 3 <https://m3.material.io/>`_ and related
`icons <https://m3.material.io/styles/icons/overview>`_



Logging
-------

`loguru <https://loguru.readthedocs.io/en/stable/>`_

Database support
----------------

`SQLite <https://www.sqlite.org/index.html>`_
